@@ -1,55 +1,44 @@
 package Data::Compare::Plugins::Set::Object;
 
-use 5.008;
 use strict;
 use warnings;
-use version 0.77; our $VERSION = qv('v1.0');
+use version 0.77; our $VERSION = qv('v1.0_1');
 use English qw(-no_match_vars);
-use Data::Compare 0.06;
-use List::Util qw(first);
+use Data::Compare;
+use List::MoreUtils qw(any);
 
 sub _register {
     return [ 'Set::Object', \&_so_set_compare ];
 }
 
 sub _so_set_compare {
-    my @sets = splice @ARG, 0, 2;
+    my @set = splice @ARG, 0, 2;
 
-    # quick optimizations if sets aren't of equal size or are directly equal
-    return 0 if $sets[0]->size() != $sets[1]->size();
-    return 1 if $sets[0]         == $sets[1];
+    return 0 if $set[0]->size != $set[1]->size;
+    return 1 if $set[0] == $set[1];
 
-    # loop over each of the first set's elements
-    # looking for a match in the second set
-    for my $element ( $sets[0]->elements() ) {
-        my $matched_element =
-            first { Data::Compare::Compare( $element, $ARG ) }
-            grep  { ref eq ref $element } $sets[1]->elements();
-
-        # return false if not found
-        return 0 if not defined $matched_element;
-
-        # otherwise remove from copy of second set and keep going
-        $sets[1]->remove($matched_element);
+    my $count = 0;
+    for my $element ( $set[0]->elements ) {
+        return 0
+          if not any { Data::Compare::Compare( $element, $ARG ) }
+            grep { ref eq ref $element } $set[1]->elements;
+        $count++;
     }
-
-    # sets are equal only if we've exhausted the second set
-    return $sets[1]->is_null();
+    return $count == $set[0]->size;
 }
 
-# Data::Compare::Plugins interface requires modules to return an arrayref
-## no critic (RequireEndWithOne)
 _register();
 
 __END__
 
 =head1 NAME
 
-Data::Compare::Plugins::Set::Object - plugin for Data::Compare to handle Set::Object objects
+Data::Compare::Plugins::Set::Object - plugin for Data::Compare to handle
+Set::Object objects
 
 =head1 VERSION
 
-This document describes Data::Compare::Plugins::Set::Object version 1.0_5
+This document describes Data::Compare::Plugins::Set::Object version 1.0
 
 =head1 SYNOPSIS
 
@@ -72,27 +61,27 @@ This document describes Data::Compare::Plugins::Set::Object version 1.0_5
 
 =head1 DESCRIPTION
 
-Enables L<Data::Compare> to Do The Right Thing for L<Set::Object> objects.
-Set::Object already has an C<equals()> method, but it only returns true if
+Enables Data::Compare to Do The Right Thing for Set::Object objects.
+Set::Object already has an equals() method, but it only returns true if
 objects within two sets are exactly equal (i.e. have the same references,
 referring to the same object instance).  When using Data::Compare in
 conjuction with this plugin, objects in sets are considered the same if their
 B<contents> are the same.  This extends down to sets that contain arrays,
 hashes, or other objects supported by Data::Compare plugins.
 
-=head1 SUBROUTINES/METHODS
+=head1 INTERFACE
 
 As a plugin to Data::Compare, the interface is the same as Data::Compare
-itself: pass the reference to two data structures to the C<Compare> function,
+itself: pass the reference to two data structures to the Compare function,
 which for historical reasons is exported by default.
 
 Set::Object also can export certain functions, and overloads comparison
-operators pertaining to sets.  Consult the
-L<Set::Object documentation|Set::Object> for more information.
+operators pertaining to sets.  Consult the Set::Object documentation for more
+information.
 
 =head1 DIAGNOSTICS
 
-See the L<documentation for Data::Compare|Data::Compare>.
+See the documentation for Data::Compare.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
@@ -102,15 +91,13 @@ Data::Compare::Plugins::Set::Object requires no configuration files or environme
 
 =over
 
-=item L<Data::Compare> >= 0.06 (must be installed separately)
+=item Data::Compare >= 0.06 (must be installed separately)
 
-=item L<Set::Object> (must be installed separately)
+=item List::MoreUtils >= 0.04 (must be installed separately)
 
-=item L<English> (part of the standard Perl 5 distribution)
+=item version >= 0.77 (part of the standard Perl 5.10.1 distribution)
 
-=item L<List::Util> (part of the standard Perl 5 distribution)
-
-=item L<version> >= 0.77 (part of the standard Perl 5.10.1 distribution)
+=item English (part of the standard Perl 5 distribution)
 
 =back
 
@@ -122,20 +109,17 @@ None reported.
 
 No bugs have been reported.
 
-Please report any bugs or feature requests via GitHub at
-L<http://github.com/mjg/Data-Compare-Plugins-Set-Object/issues>.
 Please report any bugs or feature requests to
-C<bug-data-compare-plugins-set-object@rt.cpan.org>, or through the web
-interface at L<http://rt.cpan.org>.
+C<bug-data-compare-plugins-set-object@rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org>.
 
 =head1 AUTHOR
 
-Mark Gardner <mjgardner@cpan.org>
+Mark Gardner  C<< <mjg@phoenixtrap.com> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009, Mark Gardner C<< <mjgardner@cpan.org> >>. All rights
-reserved.
+Copyright (c) 2009, Mark Gardner C<< <mjg@phoenixtrap.com> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl 5.10.1 itself.
